==> pgp4pine_1.71b.orig.tar.gz: pgp4pine-1.71b.orig/pgp4pine/defines.h <==
/* pgp4pine defines.h
 *
 * See common.c for the version and license.
 * Copyright (C) 1998 by Chris Wiegand
 */

/* ******************************************************* */

 /* If you have problems, esp. with GnuPG, and your names are all different
 * on your secret key, try uncommenting this. However, if you're like me (and
 * others) who have multiple secret keys with the same name, then DON'T
 * uncomment this. Otherwise PGP/GPG will use some key with that name, and I
 * can't predict which it'll use. I normally use the KeyID.
 * DO NOT USE THIS WITHOUT TALKING TO ME - IT SHOULD ***REALLY*** NOT BE USED!!
 * #define USE_DISPLAY_NAME
 */

#ifndef MY_DEFINES
#define MY_DEFINES

/* The following is how big of a string it allocates for the command line... */
#ifndef NAME_MAX
#define MAX_COMMAND_LINE_LENGTH 1024
#else
#define MAX_COMMAND_LINE_LENGTH NAME_MAX
#endif

#define DEBUG_LINE_LENGTH 4096
/* To make it safe, I use 4096. Should be safe, I think -- chris */

/* And this is how long the email address can be, it is 1024 for PGP5, I think... */
#define EMAIL_ADDRESS_MAX_LENGTH 1024

/* This is how long a line can be in the .pgp4pinerc file... */
#define PREFS_LINE_LENGTH 256

/* This is how long a returned line from PGP/GPG can be as far as interactive piping... */
#define CONSOLE_IO_LINE_LENGTH 256

/* This is how big a key id & type from gpg/pgp is */
#define KEY_ID_LENGTH 18
#define KEY_TYPE_LENGTH 10
#define KEY_SIZE_LENGTH 8

/* Maximum value that can be entered in for an integer argument. */
#define MAX_INT_LENGTH 256

#define MY_VERSION_STRING "1.71b"

#define NCURSES_OKAY

#endif

==> pgp4pine_1.75-6.orig.tar.gz: pgp4pine-1.75/pgp4pine/defines.h <==
/* pgp4pine defines.h
 *
 * See common.c for the version and license.
 * Copyright (C) 1998 by Chris Wiegand
 */

/* ******************************************************* */

 /* If you have problems, esp. with GnuPG, and your names are all different
 * on your secret key, try uncommenting this. However, if you're like me (and
 * others) who have multiple secret keys with the same name, then DON'T
 * uncomment this. Otherwise PGP/GPG will use some key with that name, and I
 * can't predict which it'll use. I normally use the KeyID.
 * DO NOT USE THIS WITHOUT TALKING TO ME - IT SHOULD ***REALLY*** NOT BE USED!!
 * #define USE_DISPLAY_NAME
 */

#ifndef MY_DEFINES
#define MY_DEFINES

#include "config.h"

/* The following is how big of a string it allocates for the command line... */
#ifndef NAME_MAX
#define MAX_COMMAND_LINE_LENGTH 1024
#else
#define MAX_COMMAND_LINE_LENGTH NAME_MAX
#endif

#define DEBUG_LINE_LENGTH 4096
/* To make it safe, I use 4096. Should be safe, I think -- chris */

/* And this is how long the email address can be, it is 1024 for PGP5, I think... */
#define EMAIL_ADDRESS_MAX_LENGTH 1024

/* This is how long a line can be in the .pgp4pinerc file... */
#define PREFS_LINE_LENGTH 256

/* This is how long a returned line from PGP/GPG can be as far as interactive piping... */
#define CONSOLE_IO_LINE_LENGTH 256

/* This is how big a key id & type from gpg/pgp is */
#define KEY_ID_LENGTH 18
#define KEY_TYPE_LENGTH 10
#define KEY_SIZE_LENGTH 8

/* Maximum value that can be entered in for an integer argument. */
#define MAX_INT_LENGTH 256

/* Use 'clear' to clear the screen */
#define NCURSES_OKAY

/* The current pgp4pine.cache version (byte) */
#define CACHE_VERSION 2

/* Some type declarations */
#ifndef HAVE_U_INT8_T_TYPEDEF
#undef u_int8_t	    /* maybe there is a macro with this name */
  typedef unsigned char u_int8_t;
#define HAVE_U_INT8_T_TYPEDEF
#endif
#ifndef HAVE_U_INT16_T_TYPEDEF
#undef u_int16_t        /* maybe there is a macro with this name */
#if SIZEOF_UNSIGNED_INT == 2
  typedef unsigned int   u_int16_t;
#elif SIZEOF_UNSIGNED_SHORT == 2
  typedef unsigned short u_int16_t;
#else
#error no typedef for u_int16_t
#endif
#define HAVE_U_INT16_T_TYPEDEF
#endif
#ifndef HAVE_U_INT32_T_TYPEDEF
#undef u_int32_t	    /* maybe there is a macro with this name */
#if SIZEOF_UNSIGNED_INT == 4
  typedef unsigned int u_int32_t;
#elif SIZEOF_UNSIGNED_LONG == 4
  typedef unsigned long u_int32_t;
#else
#error no typedef for u_int32_t
#endif
#define HAVE_U_INT32_T_TYPEDEF
#endif

#endif
